"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("stryker-api/core");
var MutatorHelpers_1 = require("./helpers/MutatorHelpers");
var plugin_1 = require("stryker-api/plugin");
var compiler = require('vue-template-compiler');
var VueMutator = /** @class */ (function () {
    function VueMutator(mutators) {
        this.mutators = mutators;
        this.javascriptMutatorName = 'javascript';
        this.typescriptMutatorName = 'typescript';
    }
    VueMutator.prototype.mutate = function (inputFiles) {
        var _this = this;
        var mutants = [];
        inputFiles.forEach(function (file) {
            if (file.name.endsWith('.vue')) {
                var script_1 = compiler.parseComponent(file.textContent).script;
                var _a = _this.getVueScriptMutatorAndExtension(script_1), mutator = _a.mutator, extension = _a.extension;
                var vueFile = new core_1.File(file.name + extension, file.textContent.substring(script_1.start, script_1.end));
                var vueMutants = mutator.mutate([vueFile]);
                vueMutants.forEach(function (mutant) {
                    mutant.fileName = file.name;
                    mutant.range[0] += script_1.start;
                    mutant.range[1] += script_1.start;
                });
                mutants.push.apply(mutants, vueMutants);
            }
            else {
                var mutator = _this.getMutator(file);
                mutants.push.apply(mutants, mutator.mutate([file]));
            }
        });
        return mutants;
    };
    VueMutator.prototype.getVueScriptMutatorAndExtension = function (script) {
        var lang = script.attrs.lang;
        var mutatorName;
        var extension;
        switch (lang) {
            case undefined:
            case 'js':
            case 'javascript':
                mutatorName = this.javascriptMutatorName;
                extension = '.js';
                break;
            case 'ts':
            case 'typescript':
                mutatorName = this.typescriptMutatorName;
                extension = '.ts';
                break;
            default:
                throw new Error("Found unsupported language attribute 'lang=\"" + lang + "\"' on a <script> block.");
        }
        var mutator = this.mutators[mutatorName];
        if (mutator === undefined) {
            throw new Error("The '" + mutatorName + "' mutator is required to mutate a <script> block but it was not found. Please read the README of this package for information on configuration.");
        }
        return { mutator: mutator, extension: extension };
    };
    VueMutator.prototype.getMutator = function (file) {
        var mutator = this.mutators[this.typescriptMutatorName] || this.mutators[this.javascriptMutatorName];
        if (mutator === undefined) {
            throw new Error("Unable to mutate file \"" + file.name + "\" because neither the typescript or the javascript mutator was installed. Please read the README of this package for information on configuration.");
        }
        return mutator;
    };
    VueMutator.inject = plugin_1.tokens(MutatorHelpers_1.MUTATORS_TOKEN);
    return VueMutator;
}());
exports.default = VueMutator;
//# sourceMappingURL=VueMutator.js.map